package main

import (
	"git.javil.eu/jacob1123/budgeteer/bcrypt"
	"git.javil.eu/jacob1123/budgeteer/config"
	"git.javil.eu/jacob1123/budgeteer/http"
	"git.javil.eu/jacob1123/budgeteer/jwt"
	"git.javil.eu/jacob1123/budgeteer/postgres"
)

func main() {
	cfg, err := config.LoadConfig("config.json")
	if err != nil {
		panic("Could not load Config from config.json")
	}

	bv := &bcrypt.Verifier{}
	db := postgres.Connect(cfg.DatabaseHost, cfg.DatabaseUser, cfg.DatabasePassword, cfg.DatabaseName)
	us := &postgres.UserService{DB: db}
	tv := &jwt.TokenVerifier{}

	h := &http.Handler{
		UserService:         us,
		TokenVerifier:       tv,
		CredentialsVerifier: bv,
	}
	h.Serve()
}
